<?php

namespace Btravel\Infobjects\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Btravel\Infobjects\Http\Requests\InfocategoryRequest;
use Btravel\Infobjects\Interfaces\InfocategoryRepositoryInterface;
use Btravel\Infobjects\Models\Infocategory;
use Btravel\Infobjects\Forms\Infocategory as Form;

/**
 * APIController  class for infocategory.
 */
class InfocategoryAPIController extends BaseController
{

    /**
     * Initialize infocategory resource controller.
     *
     * @param type InfocategoryRepositoryInterface $infocategory
     *
     * @return null
     */
    public function __construct(InfocategoryRepositoryInterface $infocategory)
    {
        parent::__construct();
        $this->repository = $infocategory;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Infobjects\Repositories\Criteria\InfocategoryResourceCriteria::class);
    }

    /**
     * Display a list of infocategory.
     *
     * @return Response
     */
    public function index(InfocategoryRequest $request)
    {
        return $this->repository
            ->setPresenter(\Btravel\Infobjects\Repositories\Presenter\InfocategoryPresenter::class)
            ->paginate();
    }

    /**
     * Display infocategory.
     *
     * @param Request $request
     * @param Model   $infocategory
     *
     * @return Response
     */
    public function show(InfocategoryRequest $request, Infocategory $infocategory)
    {
        return $infocategory->setPresenter(\Btravel\Infobjects\Repositories\Presenter\InfocategoryListPresenter::class);
        ;
    }

    /**
     * Create new infocategory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(InfocategoryRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('infobjects::infocategory.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('infobjects/infocategory/' . $infocategory->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('infobjects/infocategory');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the infocategory.
     *
     * @param Request $request
     * @param Model   $infocategory
     *
     * @return Response
     */
    public function update(InfocategoryRequest $request, Infocategory $infocategory)
    {
        try {
            $data = $request->all();

            $infocategory->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('infobjects::infocategory.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('infobjects/infocategory/' . $infocategory->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('infobjects/infocategory/' . $infocategory->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the infocategory.
     *
     * @param Model   $infocategory
     *
     * @return Response
     */
    public function destroy(InfocategoryRequest $request, Infocategory $infocategory)
    {
        try {
            $infocategory->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('infobjects::infocategory.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('infobjects/infocategory/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('infobjects/infocategory/' . $infocategory->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
