<?php

namespace Btravel\Infobjects\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Infobjects\Models\Infocategory;

class InfocategoryPolicy
{

    /**
     * Determine if the given user can view the infocategory.
     *
     * @param UserPolicy $user
     * @param Infocategory $infocategory
     *
     * @return bool
     */
    public function view(UserPolicy $user, Infocategory $infocategory)
    {
        if ($user->canDo('infobjects.infocategory.view') && $user->isAdmin()) {
            return true;
        }

        return $infocategory->user_id == user_id() && $infocategory->user_type == user_type();
    }

    /**
     * Determine if the given user can create a infocategory.
     *
     * @param UserPolicy $user
     * @param Infocategory $infocategory
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('infobjects.infocategory.create');
    }

    /**
     * Determine if the given user can update the given infocategory.
     *
     * @param UserPolicy $user
     * @param Infocategory $infocategory
     *
     * @return bool
     */
    public function update(UserPolicy $user, Infocategory $infocategory)
    {
        if ($user->canDo('infobjects.infocategory.edit') && $user->isAdmin()) {
            return true;
        }

        return $infocategory->user_id == user_id() && $infocategory->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given infocategory.
     *
     * @param UserPolicy $user
     * @param Infocategory $infocategory
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Infocategory $infocategory)
    {
        return $infocategory->user_id == user_id() && $infocategory->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given infocategory.
     *
     * @param UserPolicy $user
     * @param Infocategory $infocategory
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Infocategory $infocategory)
    {
        if ($user->canDo('infobjects.infocategory.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given infocategory.
     *
     * @param UserPolicy $user
     * @param Infocategory $infocategory
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Infocategory $infocategory)
    {
        if ($user->canDo('infobjects.infocategory.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
