<?php

namespace Btravel\Infobject\Providers;

use Illuminate\Support\ServiceProvider;

class InfobjectServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'infobject');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'infobject');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerInfobject();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerInfobject()
    {
        $this->app->bind('infobject', function($app) {
            return new Infobject($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Infobject', 'Lavalite\Infobject\Facades\Infobject');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('btravel.infobject', function ($app) {
            return $this->app->make('Btravel\Infobject\Infobject');
        });

        // Bind Infocategory to repository
        $this->app->bind(
            'Btravel\Infobject\Interfaces\InfocategoryRepositoryInterface',
            \Btravel\Infobject\Repositories\Eloquent\InfocategoryRepository::class
        );        // Bind Infobject to repository
        $this->app->bind(
            'Btravel\Infobject\Interfaces\InfobjectRepositoryInterface',
            \Btravel\Infobject\Repositories\Eloquent\InfobjectRepository::class
        );        // Bind Icon to repository
        $this->app->bind(
            'Btravel\Infobject\Interfaces\IconRepositoryInterface',
            \Btravel\Infobject\Repositories\Eloquent\IconRepository::class
        );

        $this->app->register(\Btravel\Infobject\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Btravel\Infobject\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and infobject's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'btravel.infobject'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeInfobject::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['btravel.infobject'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('btravel/infobject.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/infobject')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/infobject')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
