<?php

namespace Btravel\Infobject\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Btravel\Infobject\Models\Infobject;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Btravel\Infobject\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/infobject/infocategory/*')) {
            Route::bind('infocategory', function ($infocategory) {
                $infocategoryrepo = $this->app->make('Btravel\Infobject\Interfaces\InfocategoryRepositoryInterface');
                return $infocategoryrepo->findorNew($infocategory);
            });
        }
        if (Request::is('*/infobject/infobject/*')) {
            Route::bind('infobject', function ($infobject) {
                $infobjectrepo = $this->app->make('Btravel\Infobject\Interfaces\InfobjectRepositoryInterface');
                return $infobjectrepo->findorNew($infobject);
            });
        }
        if (Request::is('*/infobject/icon/*')) {
            Route::bind('icon', function ($icon) {
                $iconrepo = $this->app->make('Btravel\Infobject\Interfaces\IconRepositoryInterface');
                return $iconrepo->findorNew($icon);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
